==> fds.sdk.ProcuretoPayAPISCIM-0.22.10-py3-none-any.whl: fds/sdk/ProcuretoPayAPISCIM/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from fds.sdk.ProcuretoPayAPISCIM.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from fds.sdk.ProcuretoPayAPISCIM.model.error import Error
from fds.sdk.ProcuretoPayAPISCIM.model.file_manager_audit import FileManagerAudit
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource import FirmDescriptionResource
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource_list import FirmDescriptionResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource_meta import FirmDescriptionResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource_reference import FirmDescriptionResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource import GroupResource
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_list import GroupResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_members import GroupResourceMembers
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_meta import GroupResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_urn_scim_schemas_extension_fact_set_enterprise_hosting10_group import GroupResourceUrnScimSchemasExtensionFactSetEnterpriseHosting10Group
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_urn_scim_schemas_extension_fact_set_vrs10_group import GroupResourceUrnScimSchemasExtensionFactSetVRS10Group
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource import LocationResource
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_company_agreement_urls import LocationResourceCompanyAgreementUrls
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_list import LocationResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_meta import LocationResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_reference import LocationResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.patch import Patch
from fds.sdk.ProcuretoPayAPISCIM.model.patch_operations import PatchOperations
from fds.sdk.ProcuretoPayAPISCIM.model.pending_product_order import PendingProductOrder
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource import ProductResource
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource_list import ProductResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource_meta import ProductResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource_reference import ProductResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.schema import Schema
from fds.sdk.ProcuretoPayAPISCIM.model.schema_attributes import SchemaAttributes
from fds.sdk.ProcuretoPayAPISCIM.model.schema_list import SchemaList
from fds.sdk.ProcuretoPayAPISCIM.model.schema_meta import SchemaMeta
from fds.sdk.ProcuretoPayAPISCIM.model.schema_sub_attributes import SchemaSubAttributes
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config import ServiceProviderConfig
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_authentication_schemes import ServiceProviderConfigAuthenticationSchemes
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_bulk import ServiceProviderConfigBulk
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_change_password import ServiceProviderConfigChangePassword
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_etag import ServiceProviderConfigEtag
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_filter import ServiceProviderConfigFilter
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_patch import ServiceProviderConfigPatch
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_sort import ServiceProviderConfigSort
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource import UserClassResource
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource_list import UserClassResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource_meta import UserClassResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource_reference import UserClassResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource import UserPositionResource
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource_list import UserPositionResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource_meta import UserPositionResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource_reference import UserPositionResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource import UserResource
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_groups import UserResourceGroups
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_list import UserResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_meta import UserResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_name import UserResourceName
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_phone_numbers import UserResourcePhoneNumbers
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_core10_user import UserResourceUrnScimSchemasExtensionFactSetCore10User
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_core10_user_user_taxonomy_data import UserResourceUrnScimSchemasExtensionFactSetCore10UserUserTaxonomyData
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_vrs10_user import UserResourceUrnScimSchemasExtensionFactSetVRS10User
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_vrs10_user_domain_data import UserResourceUrnScimSchemasExtensionFactSetVRS10UserDomainData
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_vrs10_user_tenancies import UserResourceUrnScimSchemasExtensionFactSetVRS10UserTenancies

==> fds.sdk.ProcuretoPayAPISCIM-0.23.1-py3-none-any.whl: fds/sdk/ProcuretoPayAPISCIM/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from fds.sdk.ProcuretoPayAPISCIM.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from fds.sdk.ProcuretoPayAPISCIM.model.error import Error
from fds.sdk.ProcuretoPayAPISCIM.model.federation_resource import FederationResource
from fds.sdk.ProcuretoPayAPISCIM.model.federation_resource_list import FederationResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.federation_resource_location import FederationResourceLocation
from fds.sdk.ProcuretoPayAPISCIM.model.federation_resource_reference import FederationResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.federation_resource_reference_assertion_value import FederationResourceReferenceAssertionValue
from fds.sdk.ProcuretoPayAPISCIM.model.federation_resource_user import FederationResourceUser
from fds.sdk.ProcuretoPayAPISCIM.model.federation_resource_user_assertion_value import FederationResourceUserAssertionValue
from fds.sdk.ProcuretoPayAPISCIM.model.file_manager_audit import FileManagerAudit
from fds.sdk.ProcuretoPayAPISCIM.model.file_manager_audit_item import FileManagerAuditItem
from fds.sdk.ProcuretoPayAPISCIM.model.file_manager_audit_item_additional_property import FileManagerAuditItemAdditionalProperty
from fds.sdk.ProcuretoPayAPISCIM.model.file_manager_audit_item_additional_property_entity import FileManagerAuditItemAdditionalPropertyEntity
from fds.sdk.ProcuretoPayAPISCIM.model.file_manager_audit_item_additional_property_permission_override import FileManagerAuditItemAdditionalPropertyPermissionOverride
from fds.sdk.ProcuretoPayAPISCIM.model.file_manager_audit_item_additional_property_permissions import FileManagerAuditItemAdditionalPropertyPermissions
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource import FirmDescriptionResource
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource_list import FirmDescriptionResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource_meta import FirmDescriptionResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.firm_description_resource_reference import FirmDescriptionResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource import GroupResource
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_list import GroupResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_member import GroupResourceMember
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_meta import GroupResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_urn_scim_schemas_extension_fact_set_enterprise_hosting10_group import GroupResourceUrnScimSchemasExtensionFactSetEnterpriseHosting10Group
from fds.sdk.ProcuretoPayAPISCIM.model.group_resource_urn_scim_schemas_extension_fact_set_vrs10_group import GroupResourceUrnScimSchemasExtensionFactSetVRS10Group
from fds.sdk.ProcuretoPayAPISCIM.model.inline_response429 import InlineResponse429
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource import LocationResource
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_company_agreement_url import LocationResourceCompanyAgreementUrl
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_firm_description import LocationResourceFirmDescription
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_list import LocationResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_main_location import LocationResourceMainLocation
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_managing_location import LocationResourceManagingLocation
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_meta import LocationResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.location_resource_reference import LocationResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.patch import Patch
from fds.sdk.ProcuretoPayAPISCIM.model.patch_operation import PatchOperation
from fds.sdk.ProcuretoPayAPISCIM.model.patch_operation_value import PatchOperationValue
from fds.sdk.ProcuretoPayAPISCIM.model.pending_product_order import PendingProductOrder
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource import ProductResource
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource_list import ProductResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource_meta import ProductResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.product_resource_reference import ProductResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.schema import Schema
from fds.sdk.ProcuretoPayAPISCIM.model.schema_attribute import SchemaAttribute
from fds.sdk.ProcuretoPayAPISCIM.model.schema_list import SchemaList
from fds.sdk.ProcuretoPayAPISCIM.model.schema_meta import SchemaMeta
from fds.sdk.ProcuretoPayAPISCIM.model.schema_sub_attribute import SchemaSubAttribute
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config import ServiceProviderConfig
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_authentication_schemes import ServiceProviderConfigAuthenticationSchemes
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_bulk import ServiceProviderConfigBulk
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_change_password import ServiceProviderConfigChangePassword
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_etag import ServiceProviderConfigEtag
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_filter import ServiceProviderConfigFilter
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_patch import ServiceProviderConfigPatch
from fds.sdk.ProcuretoPayAPISCIM.model.service_provider_config_sort import ServiceProviderConfigSort
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource import UserClassResource
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource_list import UserClassResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource_meta import UserClassResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.user_class_resource_reference import UserClassResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource import UserPositionResource
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource_list import UserPositionResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource_meta import UserPositionResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.user_position_resource_reference import UserPositionResourceReference
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource import UserResource
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_group import UserResourceGroup
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_list import UserResourceList
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_meta import UserResourceMeta
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_name import UserResourceName
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_phone_number import UserResourcePhoneNumber
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_core10_user import UserResourceUrnScimSchemasExtensionFactSetCore10User
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_core10_user_user_taxonomy_data import UserResourceUrnScimSchemasExtensionFactSetCore10UserUserTaxonomyData
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_urn_scim_schemas_extension_fact_set_vrs10_user import UserResourceUrnScimSchemasExtensionFactSetVRS10User
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_vrs_domain_data import UserResourceVRSDomainData
from fds.sdk.ProcuretoPayAPISCIM.model.user_resource_vrs_domain_data_tenancies import UserResourceVRSDomainDataTenancies
